@@ -1,7 +1,9 @@
 '''
  ddrlib - Collection of functions used in DDR-Python scripts
+          Included in the ddr-python PyPi project
 
- *** Version: ddr-python 1.0.10 - Add continous execution option to ddr_nc_get_trigger, ddr_show_trigger
+ *** Version: ddr-python 1.0.12 - Add ddr_get_init_filename to get the name of the
+     usecase .yaml initialization file
  
  ddrlib functions interact with device management interfaces including
  NETCONF, ssh, cli, NETCONF RFC5277 notificaitons.
@@ -18,6 +20,7 @@
 
   ddrlib functions:
 
+    ddr_get_init_filename(usecase_name)
     ddr_info_msg(message)
     ddr_debug_msg(debug_flag, message)
     ddr_warning_msg(message)
@@ -65,11 +68,37 @@ import os
 import operator
 from ddrlib import *
 import genie_parsers
+from optparse import OptionParser
+
 # if running in device Guestshell import python CLI packate
 try:
     import cli
 except: pass
 
+def ddr_get_init_filename(usecase_name):
+    '''
+     Get the name of the DDR usecase initialization file
+     This file contains device information for DDR-Python scripts, other control flags
+     and usecase specific paramters.
+     The initialization filename has this format: ddr_usecase.yaml
+     If --init argument present use the argument for the initialization file
+     If no --init argument the initialization file name is the python usecase name with a ".yaml" suffix
+    '''
+    try:
+        parser = OptionParser('')
+        parser.add_option("--init", dest="init", type="string", default='none',
+                          help="Enter name of usecase YAML initialization file, default is: SCRIPT-NAME.yaml")
+        (o, args) = parser.parse_args()
+        init_file = o.init
+        if o.init == "none":
+            init_file = f"{usecase_name}.yaml"
+        else:
+            init_file = o.init
+        return init_file
+    except Exception as e:
+        print(f"*** DDR Usecase exception bad initialization file: {init_file} " + str(e))
+        sys.exit()
+
 def ddr_info_msg(message):
     """
         This function writes an info level message to the DDR execution log
@@ -531,21 +560,30 @@ def ddr_nc_get(device, access_type, xpath, leafs, return_response, debug_flag=Fa
     #
     # NETCONF connection to device for get operation using public key auth
     #
-        netconf_connection = (manager.connect(host=device[0], port=device[1],
+        try:
+            netconf_connection = (manager.connect(host=device[0], port=device[1],
                     username=device[2],
                     ssh_config=True,
                     hostkey_verify=False))
+        except Exception as e:
+            ddr_error_msg("ddr_nc_get local connection Exception: " + str(device))
+            return
     #
     # NETCONF connection to device using ssh and device credentials
     #
       else:
-        netconf_connection = (manager.connect_ssh(host=device[0], port=device[1],
-                  username=device[2],
-                  password=device[3],
-                  hostkey_verify=False,
-                  look_for_keys=False,
-                  allow_agent=False,
-                  timeout=30))
+        try:
+            netconf_connection = (manager.connect_ssh(host=device[0], port=device[1],
+                      username=device[2],
+                      password=device[3],
+                      hostkey_verify=False,
+                      look_for_keys=False,
+                      allow_agent=False,
+                      timeout=30))
+        except Exception as e:
+            ddr_error_msg("ddr_nc_get ssh connection Exception: " + str(device))
+            return
+
     #
     # get the subtree pointed to by the xpath
     #
@@ -625,21 +663,30 @@ def ddr_nc_get_config(device, access_type, xpath, leaf, return_response, debug_f
     #
     # NETCONF connection to device for get operation using public key auth
     #
-        netconf_connection = (manager.connect(host=device[0], port=device[1],
+        try:
+            netconf_connection = (manager.connect(host=device[0], port=device[1],
                     username=device[2],
                     ssh_config=True,
                     hostkey_verify=False))
+        except Exception as e:
+            ddr_error_msg("ddr_nc_get_config local connection Exception: " + str(device))
+            return
     #
     # NETCONF connection to device using ssh and device credentials
     #
       else:
-        netconf_connection = (manager.connect_ssh(host=device[0], port=device[1],
-                  username=device[2],
-                  password=device[3],
-                  hostkey_verify=False,
-                  look_for_keys=False,
-                  allow_agent=False,
-                  timeout=30))
+        try:
+            netconf_connection = (manager.connect_ssh(host=device[0], port=device[1],
+                      username=device[2],
+                      password=device[3],
+                      hostkey_verify=False,
+                      look_for_keys=False,
+                      allow_agent=False,
+                      timeout=30))
+        except Exception as e:
+            ddr_error_msg("ddr_nc_get_config ssh connection Exception: " + str(device))
+            return
+
     #
     # get the subtree pointed to by the xpath
     #
@@ -707,21 +754,29 @@ def ddr_nc_edit_config(device, access_type, datastore, commit, xpath, return_res
     #
     # NETCONF connection to device for get operation using public key auth
     #
-        netconf_connection = (manager.connect(host=device[0], port=device[1],
+        try:
+            netconf_connection = (manager.connect(host=device[0], port=device[1],
                     username=device[2],
                     ssh_config=True,
                     hostkey_verify=False))
+        except Exception as e:
+            ddr_error_msg("ddr_nc_edit_config local connection Exception: " + str(device))
+            return
     #
     # NETCONF connection to device using ssh and device credentials
     #
       else:
-        netconf_connection = (manager.connect_ssh(host=device[0], port=device[1],
-                  username=device[2],
-                  password=device[3],
-                  hostkey_verify=False,
-                  look_for_keys=False,
-                  allow_agent=False,
-                  timeout=30))
+        try:
+            netconf_connection = (manager.connect_ssh(host=device[0], port=device[1],
+                      username=device[2],
+                      password=device[3],
+                      hostkey_verify=False,
+                      look_for_keys=False,
+                      allow_agent=False,
+                      timeout=30))
+        except Exception as e:
+            ddr_error_msg("ddr_nc_edit_config ssh connection Exception: " + str(device))
+            return
     #
     # get the subtree pointed to by the xpath
     #
